=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2009-04-07 08:32:11 +0000
+++ drizzled/drizzled.cc	2009-04-07 18:04:13 +0000
@@ -249,7 +249,7 @@
 bool volatile shutdown_in_progress;
 uint32_t max_used_connections;
 const char *opt_scheduler= "multi_thread";
-const char *opt_protocol= "libdrizzleclient";
+const char *opt_protocol= "oldlibdrizzle";
 
 size_t my_thread_stack_size= 65536;
 
@@ -2432,7 +2432,7 @@
    (char**) &max_system_variables.preload_buff_size, 0, GET_ULL,
    REQUIRED_ARG, 32*1024L, 1024, 1024*1024*1024L, 0, 1, 0},
   {"protocol", OPT_SCHEDULER,
-   N_("Select protocol to be used (by default libdrizzleclient)."),
+   N_("Select protocol to be used (by default oldlibdrizzle)."),
    (char**) &opt_protocol, (char**) &opt_protocol, 0,
    GET_STR, REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
   {"query_alloc_block_size", OPT_QUERY_ALLOC_BLOCK_SIZE,

=== modified file 'drizzled/plugin/protocol.h'
--- drizzled/plugin/protocol.h	2009-04-07 06:13:48 +0000
+++ drizzled/plugin/protocol.h	2009-04-07 18:04:13 +0000
@@ -26,17 +26,6 @@
 class Session;
 class String;
 
-#if 0
-
-class Field;
-class String;
-class i_string;
-class my_decimal;
-typedef struct st_drizzle_field DRIZZLE_FIELD;
-typedef struct st_drizzle_rows DRIZZLE_ROWS;
-typedef struct st_drizzle_time DRIZZLE_TIME;
-#endif
-
 class Protocol
 {
 protected:
@@ -131,4 +120,12 @@
   virtual bool store(Field *field)=0;
 };
 
+class ProtocolFactory
+{
+public:
+  ProtocolFactory() {}
+  virtual ~ProtocolFactory() {}
+  virtual Protocol *operator()(void)= 0;
+};
+
 #endif /* DRIZZLED_PLUGIN_PROTOCOL_H */

=== modified file 'drizzled/protocol.cc'
--- drizzled/protocol.cc	2009-04-07 08:32:11 +0000
+++ drizzled/protocol.cc	2009-04-07 18:04:13 +0000
@@ -20,21 +20,15 @@
 #include <drizzled/server_includes.h>
 #include <drizzled/protocol.h>
 #include <drizzled/gettext.h>
-#include <drizzled/connect.h>
-
-typedef Protocol *(protocol_factory_t)(void);
-
-protocol_factory_t *protocol_factory;
-
-static bool protocol_inited= false; /* We must insist that only one of these plugins get loaded at a time */
-
 
 extern char *opt_protocol;
 
+ProtocolFactory *protocol_factory= NULL;
+
 Protocol *get_protocol()
 {
   assert(protocol_factory != NULL);
-  return (protocol_factory)();
+  return (*protocol_factory)();
 }
 
 int protocol_initializer(st_plugin_int *plugin)
@@ -42,7 +36,7 @@
   if (memcmp(plugin->plugin->name, opt_protocol, strlen(opt_protocol)))
     return 0;
 
-  if (protocol_inited)
+  if (protocol_factory != NULL)
   {
     fprintf(stderr, "You cannot load more then one protocol plugin\n");
     exit(1);
@@ -61,18 +55,17 @@
       return 1;
   }
 
-  protocol_inited= true;
+  plugin->data= protocol_factory;
 
   return 0;
-
 }
 
 int protocol_finalizer(st_plugin_int *plugin)
 {
   /* We know which one we initialized since its data pointer is filled */
-  if (plugin->plugin->deinit && protocol_inited)
+  if (plugin->plugin->deinit && plugin->data)
   {
-    if (plugin->plugin->deinit(NULL))
+    if (plugin->plugin->deinit((void *)plugin->data))
     {
       /* TRANSLATORS: The leading word "protocol" is the name
          of the plugin api, and so should not be translated. */

=== renamed directory 'plugin/libdrizzleclient' => 'plugin/oldlibdrizzle'
=== modified file 'plugin/oldlibdrizzle/Makefile.am'
--- plugin/libdrizzleclient/Makefile.am	2009-04-07 08:32:11 +0000
+++ plugin/oldlibdrizzle/Makefile.am	2009-04-07 18:04:13 +0000
@@ -29,7 +29,7 @@
 		drizzle_rows.h \
 		libdrizzle.h \
 		libdrizzle_priv.h \
-		libdrizzleclient.h \
+		oldlibdrizzle.h \
 		errmsg.h \
 		net_serv.h \
 		options.h \
@@ -37,15 +37,15 @@
 		password.h \
 		vio.h
 
-noinst_LTLIBRARIES= libdrizzleclient.la
-libdrizzleclient_la_SOURCES= \
+noinst_LTLIBRARIES= liboldlibdrizzle.la
+liboldlibdrizzle_la_SOURCES= \
 		client.cc \
 		drizzle.cc \
 		drizzle_data.cc \
 		errmsg.cc \
 		get_password.cc \
 		libdrizzle.cc \
-		libdrizzleclient.cc \
+		oldlibdrizzle.cc \
 		libdrizzle_priv.cc \
 		net_serv.cc \
 		pack.cc \
@@ -53,5 +53,5 @@
 		vio.cc \
 		viosocket.cc
 
-libdrizzleclient_la_LIBADD = $(LIBZ)
+liboldlibdrizzle_la_LIBADD = $(LIBZ)
 

=== renamed file 'plugin/libdrizzleclient/libdrizzleclient.cc' => 'plugin/oldlibdrizzle/oldlibdrizzle.cc'
--- plugin/libdrizzleclient/libdrizzleclient.cc	2009-04-07 08:32:11 +0000
+++ plugin/oldlibdrizzle/oldlibdrizzle.cc	2009-04-07 18:04:13 +0000
@@ -32,7 +32,7 @@
 #include <drizzled/data_home.h>
 #include "pack.h"
 #include "errmsg.h"
-#include "libdrizzleclient.h"
+#include "oldlibdrizzle.h"
 
 /*
   Function called by drizzleclient_net_init() to set some check variables
@@ -59,67 +59,67 @@
 static void write_eof_packet(Session *session, NET *net,
                              uint32_t server_status, uint32_t total_warn_count);
 
-bool Protocol_libdrizzleclient::isConnected()
+bool ProtocolOldLibdrizzle::isConnected()
 {
   return net.vio != 0;
 }
 
-void Protocol_libdrizzleclient::set_read_timeout(uint32_t timeout)
+void ProtocolOldLibdrizzle::set_read_timeout(uint32_t timeout)
 {
   drizzleclient_net_set_read_timeout(&net, timeout);
 }
 
-void Protocol_libdrizzleclient::set_write_timeout(uint32_t timeout)
+void ProtocolOldLibdrizzle::set_write_timeout(uint32_t timeout)
 {
   drizzleclient_net_set_write_timeout(&net, timeout);
 }
 
-void Protocol_libdrizzleclient::set_retry_count(uint32_t count)
+void ProtocolOldLibdrizzle::set_retry_count(uint32_t count)
 {
   net.retry_count=count;
 }
 
-void Protocol_libdrizzleclient::set_error(char error)
+void ProtocolOldLibdrizzle::set_error(char error)
 {
   net.error= error;
 }
 
-bool Protocol_libdrizzleclient::have_error(void)
+bool ProtocolOldLibdrizzle::have_error(void)
 {
   return net.error || net.vio == 0;
 }
 
-bool Protocol_libdrizzleclient::was_aborted(void)
+bool ProtocolOldLibdrizzle::was_aborted(void)
 {
   return net.error && net.vio != 0;
 }
 
-bool Protocol_libdrizzleclient::have_more_data(void)
+bool ProtocolOldLibdrizzle::have_more_data(void)
 {
   return drizzleclient_net_more_data(&net);
 }
 
-bool Protocol_libdrizzleclient::have_compression(void)
+bool ProtocolOldLibdrizzle::have_compression(void)
 {
   return net.compress;
 }
 
-void Protocol_libdrizzleclient::enable_compression(void)
+void ProtocolOldLibdrizzle::enable_compression(void)
 {
   net.compress= true;
 }
 
-bool Protocol_libdrizzleclient::is_reading(void)
+bool ProtocolOldLibdrizzle::is_reading(void)
 {
   return net.reading_or_writing == 1;
 }
 
-bool Protocol_libdrizzleclient::is_writing(void)
+bool ProtocolOldLibdrizzle::is_writing(void)
 {
   return net.reading_or_writing == 2;
 }
 
-bool Protocol_libdrizzleclient::netStoreData(const unsigned char *from, size_t length)
+bool ProtocolOldLibdrizzle::netStoreData(const unsigned char *from, size_t length)
 {
   size_t packet_length= packet->length();
   /*
@@ -150,7 +150,7 @@
   because column, table, database names fit into this limit.
 */
 
-bool Protocol_libdrizzleclient::netStoreData(const unsigned char *from, size_t length,
+bool ProtocolOldLibdrizzle::netStoreData(const unsigned char *from, size_t length,
                               const CHARSET_INFO * const from_cs,
 							  const CHARSET_INFO * const to_cs)
 {
@@ -215,7 +215,7 @@
 */
 
 #if 0
-void Protocol_libdrizzleclient::sendOK(uint32_t server_status,
+void ProtocolOldLibdrizzle::sendOK(uint32_t server_status,
                                        uint32_t total_warn_count,
             ha_rows affected_rows, uint64_t id, const char *message)
 {
@@ -252,7 +252,7 @@
   session->main_da.can_overwrite_status= false;
 }
 #endif
-void Protocol_libdrizzleclient::sendOK()
+void ProtocolOldLibdrizzle::sendOK()
 {
   unsigned char buff[DRIZZLE_ERRMSG_SIZE+10],*pos;
   const char *message= NULL;
@@ -321,7 +321,7 @@
 */
 
 #if 0
-void Protocol_libdrizzleclient::sendEOF(uint32_t server_status, uint32_t total_warn_count)
+void ProtocolOldLibdrizzle::sendEOF(uint32_t server_status, uint32_t total_warn_count)
 {
   /* Set to true if no active vio, to work well in case of --init-file */
   if (net.vio != 0)
@@ -333,7 +333,7 @@
   }
 }
 #endif
-void Protocol_libdrizzleclient::sendEOF()
+void ProtocolOldLibdrizzle::sendEOF()
 {
   /* Set to true if no active vio, to work well in case of --init-file */
   if (net.vio != 0)
@@ -375,7 +375,7 @@
   drizzleclient_net_write(net, buff, 5);
 }
 
-void Protocol_libdrizzleclient::sendErrorPacket(uint32_t sql_errno, const char *err)
+void ProtocolOldLibdrizzle::sendErrorPacket(uint32_t sql_errno, const char *err)
 {
   uint32_t length;
   /*
@@ -418,7 +418,7 @@
   critical that every error that can be intercepted is issued in one
   place only, my_message_sql.
 */
-void Protocol_libdrizzleclient::sendError(uint32_t sql_errno, const char *err)
+void ProtocolOldLibdrizzle::sendError(uint32_t sql_errno, const char *err)
 {
   assert(sql_errno);
   assert(err && err[0]);
@@ -441,20 +441,20 @@
   Default Protocol functions
 *****************************************************************************/
 
-Protocol_libdrizzleclient::Protocol_libdrizzleclient()
+ProtocolOldLibdrizzle::ProtocolOldLibdrizzle()
 {
   scramble[0]= 0;
   net.vio= 0;
 }
 
-void Protocol_libdrizzleclient::setSession(Session *session_arg)
+void ProtocolOldLibdrizzle::setSession(Session *session_arg)
 {
   session= session_arg;
   packet= &session->packet;
   convert= &session->convert_buffer;
 }
 
-bool Protocol_libdrizzleclient::flush()
+bool ProtocolOldLibdrizzle::flush()
 {
   return drizzleclient_net_flush(&net);
 }
@@ -478,7 +478,7 @@
     1	Error  (Note that in this case the error is not sent to the
     client)
 */
-bool Protocol_libdrizzleclient::send_fields(List<Item> *list, uint32_t flags)
+bool ProtocolOldLibdrizzle::send_fields(List<Item> *list, uint32_t flags)
 {
   List_iterator_fast<Item> it(*list);
   Item *item;
@@ -576,7 +576,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::write()
+bool ProtocolOldLibdrizzle::write()
 {
   return(drizzleclient_net_write(&net, (unsigned char*) packet->ptr(),
                            packet->length()));
@@ -597,7 +597,7 @@
     1		error
 */
 
-bool Protocol_libdrizzleclient::store(const char *from, const CHARSET_INFO * const cs)
+bool ProtocolOldLibdrizzle::store(const char *from, const CHARSET_INFO * const cs)
 {
   if (!from)
     return store_null();
@@ -610,7 +610,7 @@
   Send a set of strings as one long string with ',' in between.
 */
 
-bool Protocol_libdrizzleclient::store(I_List<i_string>* str_list)
+bool ProtocolOldLibdrizzle::store(I_List<i_string>* str_list)
 {
   char buf[256];
   String tmp(buf, sizeof(buf), &my_charset_bin);
@@ -630,12 +630,12 @@
 }
 
 
-bool Protocol_libdrizzleclient::store(String *str)
+bool ProtocolOldLibdrizzle::store(String *str)
 {
   return store((char*) str->ptr(), str->length(), str->charset());
 }
 
-void Protocol_libdrizzleclient::free()
+void ProtocolOldLibdrizzle::free()
 {
   packet->free();
 }
@@ -649,24 +649,24 @@
   All data are sent as 'packed-string-length' followed by 'string-data'
 ****************************************************************************/
 
-void Protocol_libdrizzleclient::init_random(uint64_t seed1, uint64_t seed2)
+void ProtocolOldLibdrizzle::init_random(uint64_t seed1, uint64_t seed2)
 {
   drizzleclient_randominit(&rand, seed1, seed2);
 }
 
-bool Protocol_libdrizzleclient::init_file_descriptor(int fd)
+bool ProtocolOldLibdrizzle::init_file_descriptor(int fd)
 {
   if (drizzleclient_net_init_sock(&net, fd, 0))
     return true;
   return false;
 }
 
-int Protocol_libdrizzleclient::file_descriptor(void)
+int ProtocolOldLibdrizzle::file_descriptor(void)
 {
   return drizzleclient_net_get_sd(&net);
 }
 
-bool Protocol_libdrizzleclient::authenticate()
+bool ProtocolOldLibdrizzle::authenticate()
 {
   bool connection_is_valid;
 
@@ -692,7 +692,7 @@
   return true;
 }
 
-bool Protocol_libdrizzleclient::read_command(char **l_packet, uint32_t *packet_length)
+bool ProtocolOldLibdrizzle::read_command(char **l_packet, uint32_t *packet_length)
 {
   /*
     This thread will do a blocking read from the client which
@@ -755,7 +755,7 @@
   return true;
 }
 
-void Protocol_libdrizzleclient::close(void)
+void ProtocolOldLibdrizzle::close(void)
 {
   if (net.vio)
   { 
@@ -764,12 +764,12 @@
   }
 }
 
-void Protocol_libdrizzleclient::prepare_for_resend()
+void ProtocolOldLibdrizzle::prepare_for_resend()
 {
   packet->length(0);
 }
 
-bool Protocol_libdrizzleclient::store_null()
+bool ProtocolOldLibdrizzle::store_null()
 {
   char buff[1];
   buff[0]= (char)251;
@@ -782,7 +782,7 @@
   and store in network buffer.
 */
 
-bool Protocol_libdrizzleclient::storeStringAux(const char *from, size_t length,
+bool ProtocolOldLibdrizzle::storeStringAux(const char *from, size_t length,
                                 const CHARSET_INFO * const fromcs,
 								const CHARSET_INFO * const tocs)
 {
@@ -799,7 +799,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store(const char *from, size_t length,
+bool ProtocolOldLibdrizzle::store(const char *from, size_t length,
                           const CHARSET_INFO * const fromcs,
 						  const CHARSET_INFO * const tocs)
 {
@@ -807,7 +807,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store(const char *from, size_t length,
+bool ProtocolOldLibdrizzle::store(const char *from, size_t length,
                           const CHARSET_INFO * const fromcs)
 {
   const CHARSET_INFO * const tocs= default_charset_info;
@@ -815,7 +815,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store_tiny(int64_t from)
+bool ProtocolOldLibdrizzle::store_tiny(int64_t from)
 {
   char buff[20];
   return netStoreData((unsigned char*) buff,
@@ -823,7 +823,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store_short(int64_t from)
+bool ProtocolOldLibdrizzle::store_short(int64_t from)
 {
   char buff[20];
   return netStoreData((unsigned char*) buff,
@@ -832,7 +832,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store_long(int64_t from)
+bool ProtocolOldLibdrizzle::store_long(int64_t from)
 {
   char buff[20];
   return netStoreData((unsigned char*) buff,
@@ -841,7 +841,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store_int64_t(int64_t from, bool unsigned_flag)
+bool ProtocolOldLibdrizzle::store_int64_t(int64_t from, bool unsigned_flag)
 {
   char buff[22];
   return netStoreData((unsigned char*) buff,
@@ -851,7 +851,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store_decimal(const my_decimal *d)
+bool ProtocolOldLibdrizzle::store_decimal(const my_decimal *d)
 {
   char buff[DECIMAL_MAX_STR_LENGTH];
   String str(buff, sizeof(buff), &my_charset_bin);
@@ -860,21 +860,21 @@
 }
 
 
-bool Protocol_libdrizzleclient::store(float from, uint32_t decimals, String *buffer)
+bool ProtocolOldLibdrizzle::store(float from, uint32_t decimals, String *buffer)
 {
   buffer->set_real((double) from, decimals, session->charset());
   return netStoreData((unsigned char*) buffer->ptr(), buffer->length());
 }
 
 
-bool Protocol_libdrizzleclient::store(double from, uint32_t decimals, String *buffer)
+bool ProtocolOldLibdrizzle::store(double from, uint32_t decimals, String *buffer)
 {
   buffer->set_real(from, decimals, session->charset());
   return netStoreData((unsigned char*) buffer->ptr(), buffer->length());
 }
 
 
-bool Protocol_libdrizzleclient::store(Field *field)
+bool ProtocolOldLibdrizzle::store(Field *field)
 {
   if (field->is_null())
     return store_null();
@@ -894,7 +894,7 @@
     we support 0-6 decimals for time.
 */
 
-bool Protocol_libdrizzleclient::store(DRIZZLE_TIME *tm)
+bool ProtocolOldLibdrizzle::store(DRIZZLE_TIME *tm)
 {
   char buff[40];
   uint32_t length;
@@ -912,7 +912,7 @@
 }
 
 
-bool Protocol_libdrizzleclient::store_date(DRIZZLE_TIME *tm)
+bool ProtocolOldLibdrizzle::store_date(DRIZZLE_TIME *tm)
 {
   char buff[MAX_DATE_STRING_REP_LENGTH];
   size_t length= my_date_to_str(tm, buff);
@@ -926,7 +926,7 @@
     we support 0-6 decimals for time.
 */
 
-bool Protocol_libdrizzleclient::store_time(DRIZZLE_TIME *tm)
+bool ProtocolOldLibdrizzle::store_time(DRIZZLE_TIME *tm)
 {
   char buff[40];
   uint32_t length;
@@ -941,7 +941,7 @@
   return netStoreData((unsigned char*) buff, length);
 }
 
-bool Protocol_libdrizzleclient::checkConnection(void)
+bool ProtocolOldLibdrizzle::checkConnection(void)
 {
   uint32_t pkt_len= 0;
   char *end;
@@ -1107,34 +1107,32 @@
   return session->checkUser(passwd, passwd_len, l_db);
 }
 
-Protocol *libdrizzleclient_protocol_factory(void)
-{
-  return new Protocol_libdrizzleclient;
-}
-
-typedef Protocol *(protocol_factory_t)(void);
-
 static int init(void *p)
 {
-  protocol_factory_t **protocol_factory= (protocol_factory_t **) p;
-
-  *protocol_factory= libdrizzleclient_protocol_factory;
-
-  return 0;
-}
-
-drizzle_declare_plugin(libdrizzleclient)
+  ProtocolFactory **factory= (ProtocolFactory **)p;
+  *factory= new ProtocolFactoryOldLibdrizzle;
+  return 0;
+}
+
+static int deinit(void *p)
+{
+  ProtocolFactoryOldLibdrizzle *factory= (ProtocolFactoryOldLibdrizzle *)p;
+  delete factory;
+  return 0;
+}
+
+drizzle_declare_plugin(oldlibdrizzle)
 {
   DRIZZLE_PROTOCOL_PLUGIN,
-  "libdrizzleclient",
+  "oldlibdrizzle",
   "0.1",
   "Eric Day",
-  "Old libdrizzleclient protocol",
+  "Old libdrizzle Protocol",
   PLUGIN_LICENSE_GPL,
-  init, /* Plugin Init */
-  NULL, /* Plugin Deinit */
-  NULL, /* status variables */
-  NULL, /* system variables */
-  NULL  /* config options */
+  init,   /* Plugin Init */
+  deinit, /* Plugin Deinit */
+  NULL,   /* status variables */
+  NULL,   /* system variables */
+  NULL    /* config options */
 }
 drizzle_declare_plugin_end;

=== renamed file 'plugin/libdrizzleclient/libdrizzleclient.h' => 'plugin/oldlibdrizzle/oldlibdrizzle.h'
--- plugin/libdrizzleclient/libdrizzleclient.h	2009-04-07 08:32:11 +0000
+++ plugin/oldlibdrizzle/oldlibdrizzle.h	2009-04-07 18:04:13 +0000
@@ -17,25 +17,25 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_LIBDRIZZLECLIENT_PROTOCOL_H
-#define DRIZZLED_LIBDRIZZLECLIENT_PROTOCOL_H
+#ifndef DRIZZLED_PLUGIN_OLDLIBDRIZZLE_H
+#define DRIZZLED_PLUGIN_OLDLIBDRIZZLE_H
 
 #include <drizzled/plugin/protocol.h>
-#include <drizzled/sql_list.h>
-#include <drizzled/item.h>
+
 #include "net_serv.h"
 #include "password.h"
 
+#if 0
 class Field;
-class String;
 class i_string;
 class my_decimal;
 typedef struct st_vio Vio;
 typedef struct st_drizzle_field DRIZZLE_FIELD;
 typedef struct st_drizzle_rows DRIZZLE_ROWS;
 typedef struct st_drizzle_time DRIZZLE_TIME;
+#endif
 
-class Protocol_libdrizzleclient :public Protocol
+class ProtocolOldLibdrizzle: public Protocol
 {
 private:
   NET net;
@@ -62,10 +62,8 @@
   bool checkConnection(void);
 
 public:
-  Protocol_libdrizzleclient();
-
+  ProtocolOldLibdrizzle();
   virtual void setSession(Session *session_arg);
-
   virtual bool isConnected();
 
   virtual void set_read_timeout(uint32_t timeout);
@@ -122,4 +120,13 @@
   virtual bool store(Field *field);
 };
 
-#endif /* DRIZZLED_LIBDRIZZLECLIENT_PROTOCOL_H */
+class ProtocolFactoryOldLibdrizzle: public ProtocolFactory
+{
+public:
+  Protocol *operator()(void)
+  {
+    return new ProtocolOldLibdrizzle;
+  }
+};
+
+#endif /* DRIZZLED_PLUGIN_OLDLIBDRIZZLE_H */

=== modified file 'plugin/oldlibdrizzle/plug.in'
--- plugin/libdrizzleclient/plug.in	2009-04-07 08:32:11 +0000
+++ plugin/oldlibdrizzle/plug.in	2009-04-07 18:04:13 +0000
@@ -1,3 +1,3 @@
-DRIZZLE_PLUGIN(libdrizzleclient,  [Old libdrizzleclient Protocol])
-DRIZZLE_PLUGIN_STATIC(libdrizzleclient,   [libdrizzleclient.la])
-DRIZZLE_PLUGIN_MANDATORY(libdrizzleclient)  dnl Default
+DRIZZLE_PLUGIN(oldlibdrizzle,  [Old libdrizzle Protocol])
+DRIZZLE_PLUGIN_STATIC(oldlibdrizzle,   [liboldlibdrizzle.la])
+DRIZZLE_PLUGIN_MANDATORY(oldlibdrizzle)  dnl Default

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2009-04-07 08:32:11 +0000
+++ po/POTFILES.in	2009-04-07 18:04:13 +0000
@@ -36,13 +36,13 @@
 mysys/my_error.cc
 mysys/my_getopt.cc
 plugin/errmsg_stderr/errmsg_stderr.cc
-plugin/libdrizzleclient/client.cc
-plugin/libdrizzleclient/drizzle.cc
-plugin/libdrizzleclient/errmsg.cc
 plugin/logging_gearman/logging_gearman.cc
 plugin/logging_query/logging_query.cc
 plugin/logging_syslog/logging_syslog.cc
 plugin/multi_thread/multi_thread.cc
+plugin/oldlibdrizzle/client.cc
+plugin/oldlibdrizzle/drizzle.cc
+plugin/oldlibdrizzle/errmsg.cc
 plugin/pool_of_threads/pool_of_threads.cc
 plugin/pool_of_threads/session_scheduler.cc
 plugin/protobuf_replicator/protobuf_replicator.cc

